@@ -119,7 +119,7 @@ class SkillConfigUpdater:  # pylint: disable=too-few-public-methods
     ) -> None:
         """Update the handlers section of the skill configuration."""
         config.handlers = CRUDCollection[SkillComponentConfiguration]()
-        config.handlers.create("abci", SkillComponentConfiguration("ABCIRoundHandler"))
+        config.handlers.create("abci", SkillComponentConfiguration("ABCIHandler"))
         config.handlers.create(
             "contract_api", SkillComponentConfiguration("ContractApiHandler")
         )
@@ -236,7 +236,10 @@ class SkillConfigUpdater:  # pylint: disable=too-few-public-methods
             "round_timeout_seconds": 30.0,
             "service_id": service_id,
             "service_registry_address": None,
-            "setup": {},
+            "setup": {
+                "all_participants": [["0x0000000000000000000000000000000000000000"]],
+                "safe_contract_address": ["0x0000000000000000000000000000000000000000"],
+            },
             "sleep_time": 1,
             "tendermint_check_sleep_delay": 3,
             "tendermint_com_url": "http://localhost:8080",
