@@ -69,10 +69,11 @@ class ROUNDS:
     class {RoundCls}({ABCRoundCls}):
         \"\"\"{RoundCls}\"\"\"
 
+        allowed_tx_type = {PayloadCls}.transaction_type
+        payload_attribute = {PayloadCls}.transaction_type.value
+        synchronized_data_class = SynchronizedData
+
         {todo_abstract_round_cls}
-        allowed_tx_type: Optional[TransactionType] = {PayloadCls}.transaction_type
-        # TODO: set the correct payload attribute
-        payload_attribute: str
 
         def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
             \"\"\"Process the end of the block.\"\"\"
@@ -122,6 +123,7 @@ class BEHAVIOURS:
     HEADER = """\
     \"\"\"This package contains round behaviours of {AbciApp}.\"\"\"
 
+    from abc import ABC
     from typing import Generator, Set, Type, cast
 
     from packages.valory.skills.abstract_round_abci.base import AbstractRound
@@ -143,8 +145,8 @@ class BEHAVIOURS:
     """
 
     BASE_BEHAVIOUR_CLS = """\
-    class {BaseBehaviourCls}(BaseBehaviour):
-        \"\"\"Base behaviour for the common apps' skill.\"\"\"
+    class {BaseBehaviourCls}(BaseBehaviour, ABC):
+        \"\"\"Base behaviour for the {skill_name} skill.\"\"\"
 
         @property
         def synchronized_data(self) -> SynchronizedData:
@@ -164,7 +166,7 @@ class BEHAVIOURS:
 
         matching_round: Type[AbstractRound] = {matching_round}
 
-        # TODO: implement logic required to set payload content (e.g. synchronized_data)
+        # TODO: implement logic required to set payload content for synchronization
         def async_act(self) -> Generator:
             \"\"\"Do the act, supporting asynchronous execution.\"\"\"
 
@@ -211,7 +213,6 @@ class PAYLOADS:
     class TransactionType(Enum):
         \"\"\"Enumeration of transaction types.\"\"\"
 
-        # TODO: define transaction types: e.g. TX_HASH: "tx_hash"
         {tx_types}
 
         def __str__(self) -> str:
@@ -229,7 +230,7 @@ class PAYLOADS:
 
             super().__init__(sender, **kwargs)
             setattr(self, f"_{{self.transaction_type}}", content)
-            p = property(lambda s: getattr(self, f"_{{self.transaction_type}}"))
+            p = property(lambda self: getattr(self, f"_{{self.transaction_type}}"))
             setattr(self.__class__, f"{{self.transaction_type}}", p)
 
         @property
@@ -313,7 +314,7 @@ class HANDLERS:
     )
 
 
-    ABCIRoundHandler = BaseABCIRoundHandler
+    ABCIHandler = BaseABCIRoundHandler
     HttpHandler = BaseHttpHandler
     SigningHandler = BaseSigningHandler
     LedgerApiHandler = BaseLedgerApiHandler
