@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -29,6 +29,7 @@ from aea_test_autonomy.base_test_classes.agents import (
     BaseTestEnd2EndExecution,
     RoundChecks,
 )
+from aea_test_autonomy.configurations import KEY_PAIRS
 from aea_test_autonomy.fixture_helpers import (  # noqa: F401
     abci_host,
     abci_port,
@@ -69,6 +70,7 @@ STRICT_CHECK_STRINGS = (
 
 
 # normal execution
+@pytest.mark.e2e
 class BaseHelloWorldABCITest(
     BaseTestEnd2EndExecution,
 ):
@@ -78,6 +80,7 @@ class BaseHelloWorldABCITest(
     skill_package = "valory/hello_world_abci:0.1.0"
     wait_to_finish = 160
     happy_path = HAPPY_PATH
+    key_pairs = KEY_PAIRS
     strict_check_strings: Tuple[str, ...] = STRICT_CHECK_STRINGS
     package_registry_src_rel = Path(__file__).parent.parent.parent.parent.parent
 
@@ -147,7 +150,7 @@ class TestHelloWorldABCIFourAgentsTwoAgentRestarting(BaseHelloWorldABCITestCatch
     n_terminal = 2
 
 
-@pytest.mark.skip(reason="not working atm")
+@pytest.mark.skip(reason="https://github.com/valory-xyz/open-autonomy/issues/1709")
 @pytest.mark.parametrize("nb_nodes", (1,))
 class TestHelloWorldABCISingleAgentGrpc(
     BaseHelloWorldABCITest,
@@ -158,7 +161,7 @@ class TestHelloWorldABCISingleAgentGrpc(
     strict_check_strings = STRICT_CHECK_STRINGS + ("Starting gRPC server",)
 
 
-@pytest.mark.skip(reason="not working atm")
+@pytest.mark.skip(reason="https://github.com/valory-xyz/open-autonomy/issues/1709")
 @pytest.mark.parametrize("nb_nodes", (2,))
 class TestHelloWorldABCITwoAgentsGrpc(
     BaseHelloWorldABCITest,
@@ -169,7 +172,7 @@ class TestHelloWorldABCITwoAgentsGrpc(
     strict_check_strings = STRICT_CHECK_STRINGS + ("Starting gRPC server",)
 
 
-@pytest.mark.skip(reason="not working atm")
+@pytest.mark.skip(reason="https://github.com/valory-xyz/open-autonomy/issues/1709")
 @pytest.mark.parametrize("nb_nodes", (4,))
 class TestHelloWorldABCIFourAgentsGrpc(
     BaseHelloWorldABCITest,
