@@ -29,6 +29,7 @@ from aea_test_autonomy.base_test_classes.agents import (
     BaseTestEnd2EndExecution,
     RoundChecks,
 )
+from aea_test_autonomy.configurations import KEY_PAIRS
 from aea_test_autonomy.fixture_helpers import (  # noqa: F401
     abci_host,
     abci_port,
@@ -63,6 +64,7 @@ class TestRaceConditionTendermintReset(BaseTestEnd2EndExecution):
     agent_package = "valory/register_reset:0.1.0"
     skill_package = "valory/register_reset_abci:0.1.0"
     happy_path = HAPPY_PATH
+    key_pairs = KEY_PAIRS
     wait_to_finish = 200
     __reset_tendermint_every = 1
     package_registry_src_rel = Path(__file__).parents[4]
