@@ -17,4 +17,4 @@
 #
 # ------------------------------------------------------------------------------
 
-"""Abci connection."""
+"""Abci connection."""  # pragma: nocover
