@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -51,7 +51,7 @@ from packages.valory.connections.abci.tendermint.crypto.proof_pb2 import (  # ty
 )
 from packages.valory.protocols.abci import AbciMessage
 from packages.valory.protocols.abci.custom_types import (
-    ConsensusParams as CustomConsensusParams,  # type: ignore
+    ConsensusParams as CustomConsensusParams,
 )
 from packages.valory.protocols.abci.custom_types import Event as CustomEvent
 from packages.valory.protocols.abci.custom_types import (
