@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ import math
 import pprint
 import re
 import sys
-from abc import ABC, abstractmethod
+from abc import ABC, ABCMeta, abstractmethod
 from enum import Enum
 from functools import partial, wraps
 from typing import (
@@ -42,7 +42,7 @@ from typing import (
     cast,
 )
 
-import pytz  # type: ignore  # pylint: disable=import-error
+import pytz  # pylint: disable=import-error
 from aea.exceptions import enforce
 from aea.protocols.base import Message
 from aea.protocols.dialogue.base import Dialogue
@@ -121,6 +121,14 @@ class TimeoutException(Exception):
     """Exception raised when a timeout during AsyncBehaviour occurs."""
 
 
+class BaseBehaviourInternalError(Exception):
+    """Internal error due to a bad implementation of the BaseBehaviour."""
+
+    def __init__(self, message: str, *args: Any) -> None:
+        """Initialize the error object."""
+        super().__init__("internal error: " + message, *args)
+
+
 class AsyncBehaviour(ABC):
     """
     MixIn behaviour class that support limited asynchronous programming.
@@ -390,7 +398,7 @@ class IPFSBehaviour(SimpleBehaviour, ABC):
         # If params are not found `AttributeError` will be raised. This is fine, because something will have gone wrong.
         # If `ipfs_domain_name` is not specified for the skill, then we get a `None` default.
         # Therefore, `IPFSBehaviour` will be disabled.
-        domain = getattr(self.params, "ipfs_domain_name", None)  # type: ignore  # pylint: disable=E1101
+        domain = getattr(self.params, "ipfs_domain_name", None)  # pylint: disable=E1101
         loader_cls = kwargs.pop("loader_cls", Loader)
         storer_cls = kwargs.pop("storer_cls", Storer)
         if domain is not None:  # pragma: nocover
@@ -483,15 +491,63 @@ class RPCResponseStatus(Enum):
     UNCLASSIFIED_ERROR = 6
 
 
-class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
-    """Base class for FSM behaviours."""
+class _MetaBaseBehaviour(ABCMeta):
+    """A metaclass that validates BaseBehaviour's attributes."""
+
+    def __new__(mcs, name: str, bases: Tuple, namespace: Dict, **kwargs: Any) -> Type:  # type: ignore
+        """Initialize the class."""
+        new_cls = super().__new__(mcs, name, bases, namespace, **kwargs)
+
+        if ABC in bases:
+            # abstract class, return
+            return new_cls
+        if not issubclass(new_cls, BaseBehaviour):
+            # the check only applies to AbciApp subclasses
+            return new_cls
+
+        mcs._check_consistency(cast(Type[BaseBehaviour], new_cls))
+        return new_cls
+
+    @classmethod
+    def _check_consistency(mcs, base_behaviour_cls: Type["BaseBehaviour"]) -> None:
+        """Check consistency of class attributes."""
+        mcs._check_required_class_attributes(base_behaviour_cls)
+
+    @classmethod
+    def _check_required_class_attributes(
+        mcs, base_behaviour_cls: Type["BaseBehaviour"]
+    ) -> None:
+        """Check that required class attributes are set."""
+        if not hasattr(base_behaviour_cls, "matching_round"):
+            raise BaseBehaviourInternalError(
+                f"'matching_round' not set on {base_behaviour_cls}"
+            )
+
+
+class BaseBehaviour(
+    AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC, metaclass=_MetaBaseBehaviour
+):
+    """
+    This class represents the base class for FSM behaviours
+
+    A behaviour is a state of the FSM App execution. It usually involves
+    interactions between participants in the FSM App,
+    although this is not enforced at this level of abstraction.
+
+    Concrete classes must set:
+    - matching_round: the round class matching the behaviour;
+
+    Optionally, behaviour_id can be defined, although it is recommended to use the autogenerated id.
+    """
 
     __pattern = re.compile(r"(?<!^)(?=[A-Z])")
     is_programmatically_defined = True
-    behaviour_id: str
-    matching_round: Type[AbstractRound]
     is_degenerate: bool = False
 
+    matching_round: Type[AbstractRound]
+
+    behaviour_id: str
+
     def __init__(self, **kwargs: Any):  # pylint: disable=super-init-not-called
         """Initialize a base behaviour."""
         AsyncBehaviour.__init__(self)
@@ -503,7 +559,6 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
         self._timeout: float = 0
         self._is_healthy: bool = False
         self._non_200_return_code_count: int = 0
-        enforce(self.behaviour_id != "", "State id not set.")
 
     @classmethod
     def auto_behaviour_id(cls) -> str:
@@ -1847,14 +1902,18 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
         return True
 
 
-class TmManager(BaseBehaviour, ABC):
+class TmManager(BaseBehaviour):
     """Util class to be used for managing the tendermint node."""
 
     _active_generator: Optional[Generator] = None
     _hard_reset_sleep = 20.0  # 20s
     _max_reset_retry = 5
 
-    def async_act(self) -> Generator:  # type: ignore
+    # TODO: TmManager is not a BaseBehaviour. It should be
+    # redesigned!
+    matching_round = Type[AbstractRound]
+
+    def async_act(self) -> Generator:
         """The behaviour act."""
         self.context.logger.error(
             f"{type(self).__name__}'s async_act was called. "
@@ -2020,8 +2079,9 @@ class DegenerateBehaviour(BaseBehaviour, ABC):
 
     matching_round: Type[AbstractRound]
     is_degenerate: bool = True
+    sleep_time_before_exit = 5.0
 
-    def async_act(self) -> Generator:  # type: ignore
+    def async_act(self) -> Generator:
         """Exit the agent with error when a degenerate round is reached."""
         self.context.logger.error(
             "The execution reached a degenerate behaviour. "
@@ -2029,16 +2089,24 @@ class DegenerateBehaviour(BaseBehaviour, ABC):
             "the execution of the ABCI application. Please check the "
             "functioning of the ABCI app."
         )
+        self.context.logger.error(
+            f"Sleeping {self.sleep_time_before_exit} seconds before exiting."
+        )
+        yield from self.sleep(self.sleep_time_before_exit)
         error_code = 1
         sys.exit(error_code)
 
 
-def make_degenerate_behaviour(round_id: str) -> Type[DegenerateBehaviour]:
+def make_degenerate_behaviour(
+    round_cls: Type[AbstractRound],
+) -> Type[DegenerateBehaviour]:
     """Make a degenerate behaviour class."""
 
     class NewDegenerateBehaviour(DegenerateBehaviour):
         """A newly defined degenerate behaviour class."""
 
+        matching_round = round_cls
+
     new_behaviour_cls = NewDegenerateBehaviour
-    new_behaviour_cls.__name__ = f"DegenerateBehaviour_{round_id}"  # type: ignore # pylint: disable=attribute-defined-outside-init
-    return new_behaviour_cls  # type: ignore
+    new_behaviour_cls.__name__ = f"DegenerateBehaviour_{round_cls.auto_round_id()}"  # pylint: disable=attribute-defined-outside-init
+    return new_behaviour_cls
