@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@
 
 """Tests for valory/abstract_round_abci skill's behaviours."""
 import json
+from abc import ABC
 from copy import copy
 from enum import Enum
 from pathlib import Path
@@ -63,7 +64,7 @@ from packages.valory.skills.abstract_round_abci.handlers import (
 # pylint: disable=protected-access,too-few-public-methods,consider-using-with
 
 
-class FSMBehaviourBaseCase(BaseSkillTestCase):
+class FSMBehaviourBaseCase(BaseSkillTestCase, ABC):
     """Base case for testing FSMBehaviour classes."""
 
     path_to_skill: Path
@@ -75,10 +76,14 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
     tendermint_handler: TendermintHandler
     old_tx_type_to_payload_cls: Dict[str, Type[BaseTxPayload]]
     benchmark_dir: TemporaryDirectory
+    default_ledger: str = "ethereum"
 
     @classmethod
     def setup_class(cls, **kwargs: Any) -> None:
         """Setup the test class."""
+        if not hasattr(cls, "path_to_skill"):
+            raise ValueError(f"No `path_to_skill` set on {cls}")  # pragma: nocover
+            # works once https://github.com/valory-xyz/open-aea/issues/492 is fixed
         # we need to store the current value of the meta-class attribute
         # _MetaPayload.transaction_type_to_payload_cls, and restore it
         # in the teardown function. We do a shallow copy so we avoid
@@ -87,29 +92,46 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
             _MetaPayload.transaction_type_to_payload_cls
         )
         _MetaPayload.transaction_type_to_payload_cls = {}
-        super().setup_class()  # pylint: disable=no-value-for-parameter
-        assert cls._skill.skill_context._agent_context is not None  # nosec
+        super().setup_class(**kwargs)  # pylint: disable=no-value-for-parameter
+        assert (
+            cls._skill.skill_context._agent_context is not None
+        ), "Agent context not set"  # nosec
         cls._skill.skill_context._agent_context.identity._default_address_key = (
-            "ethereum"
-        )
-        cls._skill.skill_context._agent_context._default_ledger_id = "ethereum"
-        cls.behaviour = cast(
-            AbstractRoundBehaviour,
-            cls._skill.skill_context.behaviours.main,
-        )
-        cls.http_handler = cast(HttpHandler, cls._skill.skill_context.handlers.http)
-        cls.signing_handler = cast(
-            SigningHandler, cls._skill.skill_context.handlers.signing
-        )
-        cls.contract_handler = cast(
-            ContractApiHandler, cls._skill.skill_context.handlers.contract_api
-        )
-        cls.ledger_handler = cast(
-            LedgerApiHandler, cls._skill.skill_context.handlers.ledger_api
-        )
-        cls.tendermint_handler = cast(
-            TendermintHandler, cls._skill.skill_context.handlers.tendermint
+            cls.default_ledger
         )
+        cls._skill.skill_context._agent_context._default_ledger_id = cls.default_ledger
+        behaviour = cls._skill.skill_context.behaviours.main
+        assert isinstance(
+            behaviour, AbstractRoundBehaviour
+        ), f"{behaviour} is not of type {AbstractRoundBehaviour}"
+        cls.behaviour = behaviour
+        for attr, handler, handler_type in [
+            ("http_handler", cls._skill.skill_context.handlers.http, HttpHandler),
+            (
+                "signing_handler",
+                cls._skill.skill_context.handlers.signing,
+                SigningHandler,
+            ),
+            (
+                "contract_handler",
+                cls._skill.skill_context.handlers.contract_api,
+                ContractApiHandler,
+            ),
+            (
+                "ledger_handler",
+                cls._skill.skill_context.handlers.ledger_api,
+                LedgerApiHandler,
+            ),
+            (
+                "tendermint_handler",
+                cls._skill.skill_context.handlers.tendermint,
+                TendermintHandler,
+            ),
+        ]:
+            assert isinstance(
+                handler, handler_type
+            ), f"{handler} is not of type {handler_type}"
+            setattr(cls, attr, handler)
 
         if kwargs.get("param_overrides") is not None:
             for param_name, param_value in kwargs["param_overrides"].items():
@@ -123,7 +145,7 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
 
         :param kwargs: the keyword arguments passed to _prepare_skill
         """
-        super().setup()
+        super().setup(**kwargs)
         self.behaviour.setup()
         self._skill.skill_context.state.setup()
         self._skill.skill_context.state.round_sequence.end_sync()
@@ -393,11 +415,11 @@ class FSMBehaviourBaseCase(BaseSkillTestCase):
     @classmethod
     def teardown_class(cls) -> None:
         """Teardown the test class."""
-        _MetaPayload.transaction_type_to_payload_cls = cls.old_tx_type_to_payload_cls  # type: ignore
+        _MetaPayload.transaction_type_to_payload_cls = cls.old_tx_type_to_payload_cls
 
-    def teardown(self) -> None:
+    def teardown(self, **kwargs: Any) -> None:
         """Teardown."""
-        super().teardown()
+        super().teardown(**kwargs)
         self.benchmark_dir.cleanup()
 
 
