@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2022 Valory AG
+#   Copyright 2022-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -33,7 +33,6 @@ from typing import (
     Optional,
     Tuple,
     Type,
-    cast,
 )
 from unittest import mock
 
@@ -142,6 +141,7 @@ class DummyRound(AbstractRound):
 
     allowed_tx_type = DummyTxPayload.transaction_type
     payload_attribute = get_name(DummyTxPayload.value)
+    synchronized_data_class = BaseSynchronizedData
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
         """end_block method."""
@@ -208,7 +208,7 @@ class BaseRoundTestClass:  # pylint: disable=too-few-public-methods
                     all_participants=[self.participants],
                 ),
             )
-        )  # type: ignore
+        )
         self.consensus_params = ConsensusParams(max_participants=MAX_PARTICIPANTS)
 
     def _test_no_majority_event(self, round_obj: AbstractRound) -> None:
@@ -272,9 +272,8 @@ class BaseCollectDifferentUntilAllRoundTest(  # pylint: disable=too-few-public-m
         yield test_round
         assert test_round.collection_threshold_reached
 
-        actual_next_synchronized_data = cast(
-            self._synchronized_data_class,  # type: ignore
-            synchronized_data_update_fn(deepcopy(self.synchronized_data), test_round),  # type: ignore
+        actual_next_synchronized_data = synchronized_data_update_fn(
+            deepcopy(self.synchronized_data), test_round
         )
 
         res = test_round.end_block()
@@ -284,7 +283,6 @@ class BaseCollectDifferentUntilAllRoundTest(  # pylint: disable=too-few-public-m
         else:
             assert res is not None
             synchronized_data, event = res
-            synchronized_data = cast(self._synchronized_data_class, synchronized_data)  # type: ignore
             for behaviour_attr_getter in synchronized_data_attr_checks:
                 assert behaviour_attr_getter(
                     synchronized_data
@@ -332,16 +330,14 @@ class BaseCollectSameUntilAllRoundTest(
             assert test_round.collection_threshold_reached
         assert test_round.common_payload == most_voted_payload
 
-        actual_next_synchronized_data = cast(
-            self._synchronized_data_class,  # type: ignore
-            synchronized_data_update_fn(deepcopy(self.synchronized_data), test_round),  # type: ignore
+        actual_next_synchronized_data = synchronized_data_update_fn(
+            deepcopy(self.synchronized_data), test_round
         )
         res = test_round.end_block()
         yield res
         assert res is not None
 
         synchronized_data, event = res
-        synchronized_data = cast(self._synchronized_data_class, synchronized_data)  # type: ignore
 
         for behaviour_attr_getter in synchronized_data_attr_checks:
             assert behaviour_attr_getter(synchronized_data) == behaviour_attr_getter(
@@ -385,16 +381,14 @@ class BaseCollectSameUntilThresholdRoundTest(  # pylint: disable=too-few-public-
         assert test_round.threshold_reached
         assert test_round.most_voted_payload == most_voted_payload
 
-        actual_next_synchronized_data = cast(
-            self._synchronized_data_class,  # type: ignore
-            synchronized_data_update_fn(deepcopy(self.synchronized_data), test_round),  # type: ignore
+        actual_next_synchronized_data = synchronized_data_update_fn(
+            deepcopy(self.synchronized_data), test_round
         )
         res = test_round.end_block()
         yield res
         assert res is not None
 
         synchronized_data, event = res
-        synchronized_data = cast(self._synchronized_data_class, synchronized_data)  # type: ignore
 
         for behaviour_attr_getter in synchronized_data_attr_checks:
             assert behaviour_attr_getter(synchronized_data) == behaviour_attr_getter(
@@ -427,16 +421,15 @@ class BaseOnlyKeeperSendsRoundTest(  # pylint: disable=too-few-public-methods
         assert test_round.has_keeper_sent_payload
 
         yield test_round
-        actual_next_synchronized_data = cast(
-            self._synchronized_data_class,  # type: ignore
-            synchronized_data_update_fn(deepcopy(self.synchronized_data), test_round),  # type: ignore
+        actual_next_synchronized_data = synchronized_data_update_fn(
+            deepcopy(self.synchronized_data), test_round
         )
         res = test_round.end_block()
         yield res
         assert res is not None
 
         synchronized_data, event = res
-        synchronized_data = cast(self._synchronized_data_class, synchronized_data)  # type: ignore
+
         for behaviour_attr_getter in synchronized_data_attr_checks:
             assert behaviour_attr_getter(synchronized_data) == behaviour_attr_getter(
                 actual_next_synchronized_data
@@ -472,16 +465,15 @@ class BaseVotingRoundTest(BaseRoundTestClass):  # pylint: disable=too-few-public
         yield test_round
         assert threshold_check(test_round)
 
-        actual_next_synchronized_data = cast(
-            self._synchronized_data_class,  # type: ignore
-            synchronized_data_update_fn(deepcopy(self.synchronized_data), test_round),  # type: ignore
+        actual_next_synchronized_data = synchronized_data_update_fn(
+            deepcopy(self.synchronized_data), test_round
         )
         res = test_round.end_block()
         yield res
         assert res is not None
 
         synchronized_data, event = res
-        synchronized_data = cast(self._synchronized_data_class, synchronized_data)  # type: ignore
+
         for behaviour_attr_getter in synchronized_data_attr_checks:
             assert behaviour_attr_getter(synchronized_data) == behaviour_attr_getter(
                 actual_next_synchronized_data
@@ -574,16 +566,15 @@ class BaseCollectDifferentUntilThresholdRoundTest(  # pylint: disable=too-few-pu
         yield test_round
         assert test_round.collection_threshold_reached
 
-        actual_next_synchronized_data = cast(
-            self._synchronized_data_class,  # type: ignore
-            synchronized_data_update_fn(deepcopy(self.synchronized_data), test_round),  # type: ignore
+        actual_next_synchronized_data = synchronized_data_update_fn(
+            deepcopy(self.synchronized_data), test_round
         )
+
         res = test_round.end_block()
         yield res
         assert res is not None
 
         synchronized_data, event = res
-        synchronized_data = cast(self._synchronized_data_class, synchronized_data)  # type: ignore
 
         for behaviour_attr_getter in synchronized_data_attr_checks:
             assert behaviour_attr_getter(synchronized_data) == behaviour_attr_getter(
