@@ -59,6 +59,7 @@ from packages.valory.skills.abstract_round_abci.base import (
     AbciAppDB,
     AbciAppTransitionFunction,
     AbstractRound,
+    AbstractRoundInternalError,
     AddBlockError,
     AppState,
     BaseSynchronizedData,
@@ -75,6 +76,7 @@ from packages.valory.skills.abstract_round_abci.base import (
     Transaction,
     TransactionTypeNotRecognizedError,
     _MetaAbciApp,
+    _MetaAbstractRound,
     _MetaPayload,
 )
 from packages.valory.skills.abstract_round_abci.base import _logger as default_logger
@@ -226,6 +228,32 @@ def test_base_tx_payload() -> None:
     assert type(hash(payload)) == int
 
 
+def test_meta_round_abstract_round_when_instance_not_subclass_of_abstract_round() -> None:
+    """Test instantiation of meta class when instance not a subclass of abstract round."""
+
+    class MyAbstractRound(metaclass=_MetaAbstractRound):
+        pass
+
+
+def test_abstract_round_instantiation_without_attributes_raises_error() -> None:
+    """Test that definition of concrete subclass of AbstractRound without attributes raises error."""
+    with pytest.raises(AbstractRoundInternalError):
+
+        class MyRoundBehaviour(AbstractRound):
+            pass
+
+    with pytest.raises(AbstractRoundInternalError):
+
+        class MyRoundBehaviourB(AbstractRound):
+            synchronized_data_class = MagicMock()
+
+    with pytest.raises(AbstractRoundInternalError):
+
+        class MyRoundBehaviourC(AbstractRound):
+            synchronized_data_class = MagicMock()
+            allowed_tx_type = MagicMock()
+
+
 class TestTransactions:
     """Test Transactions class."""
 
@@ -992,6 +1020,7 @@ class TestBaseSynchronizedData:
         participant_to_selection = "participant_to_selection"
         participant_to_randomness = "participant_to_randomness"
         participant_to_votes = "participant_to_votes"
+        safe_contract_address = "0x0"
 
         base_synchronized_data = BaseSynchronizedData(
             db=AbciAppDB(
@@ -1005,6 +1034,7 @@ class TestBaseSynchronizedData:
                         participant_to_selection=participant_to_selection,
                         participant_to_randomness=participant_to_randomness,
                         participant_to_votes=participant_to_votes,
+                        safe_contract_address=safe_contract_address,
                     )
                 )
             )
@@ -1028,6 +1058,7 @@ class TestBaseSynchronizedData:
             == participant_to_randomness
         )
         assert base_synchronized_data.participant_to_votes == participant_to_votes
+        assert base_synchronized_data.safe_contract_address == safe_contract_address
 
 
 class TestAbstractRound:
@@ -1051,6 +1082,8 @@ class TestAbstractRound:
         class MyConcreteRound(AbstractRound):
 
             allowed_tx_type = MagicMock()
+            synchronized_data_class = MagicMock()
+            payload_attribute = MagicMock()
 
             def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
                 pass
@@ -1070,6 +1103,8 @@ class TestAbstractRound:
             # here round_id is missing
             # ...
             allowed_tx_type = MagicMock()
+            synchronized_data_class = MagicMock()
+            payload_attribute = MagicMock()
 
             def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
                 pass
@@ -1087,31 +1122,34 @@ class TestAbstractRound:
     def test_must_set_allowed_tx_type(self) -> None:
         """Test that the 'allowed_tx_type' must be set in concrete classes."""
 
-        class MyConcreteRound(AbstractRound):
-            round_id = ""
-            # here allowed_tx_type is missing
-            # ...
-
-            def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
-                pass
-
-            def check_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
-            def process_payload(self, payload: BaseTxPayload) -> None:
-                pass
-
         with pytest.raises(
-            ABCIAppInternalError, match="'allowed_tx_type' field not set"
+            AbstractRoundInternalError, match="'allowed_tx_type' not set on .*"
         ):
-            MyConcreteRound(MagicMock(), MagicMock())
+
+            class MyConcreteRound(AbstractRound):
+
+                synchronized_data_class = MagicMock()
+                payload_attribute = MagicMock()
+                # here allowed_tx_type is missing
+                # ...
+
+                def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
+                    pass
+
+                def check_payload(self, payload: BaseTxPayload) -> None:
+                    pass
+
+                def process_payload(self, payload: BaseTxPayload) -> None:
+                    pass
 
     def test_check_allowed_tx_type_with_previous_round_transaction(self) -> None:
         """Test check 'allowed_tx_type'."""
 
         class MyConcreteRound(AbstractRound):
-            round_id = ""
+
             allowed_tx_type = "allowed_tx_type"
+            synchronized_data_class = MagicMock()
+            payload_attribute = MagicMock()
 
             def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
                 pass
@@ -1136,8 +1174,10 @@ class TestAbstractRound:
         """Test check 'allowed_tx_type'."""
 
         class MyConcreteRound(AbstractRound):
-            round_id = ""
+
             allowed_tx_type = None
+            synchronized_data_class = MagicMock()
+            payload_attribute = MagicMock()
 
             def end_block(self) -> Optional[Tuple[BaseSynchronizedData, EventType]]:
                 pass
@@ -1628,7 +1668,7 @@ class TestAbciApp:
 
         assert EmptyAbciApp.background_round_cls is not None
         assert EmptyAbciApp.termination_transition_function is not None
-        assert EmptyAbciApp.termination_event is not None  # type: ignore
+        assert EmptyAbciApp.termination_event is not None
         assert sorted(EmptyAbciApp.cross_period_persisted_keys) == ["1", "2", "3"]
 
     def test_background_round(self) -> None:
@@ -1886,7 +1926,7 @@ class TestRoundSequence:
         self.round_sequence._last_round_transition_root_hash = (
             last_round_transition_root_hash
         )
-        self.round_sequence.abci_app.synchronized_data.db.round_count = round_count  # type: ignore
+        self.round_sequence.abci_app.synchronized_data.db.round_count = round_count
         self.round_sequence.abci_app._reset_index = reset_index
 
         if last_round_transition_root_hash == b"":
@@ -2275,6 +2315,10 @@ def test_meta_abci_app_when_final_round_not_subclass_of_degenerate_round() -> No
     class FinalRound(AbstractRound):
         """A round class for testing."""
 
+        allowed_tx_type = MagicMock()
+        synchronized_data_class = MagicMock()
+        payload_attribute = MagicMock()
+
         def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
             pass
 
@@ -2323,20 +2367,12 @@ def test_synchronized_data_type_on_abci_app_init(caplog: LogCaptureFixture) -> N
     # this is how it's setup in SharedState.setup, using BaseSynchronizedData
     synchronized_data = BaseSynchronizedData(db=AbciAppDB(setup_data={}))
 
-    with caplog.at_level(logging.WARNING):
-        abci_app = AbciAppTest(synchronized_data, MagicMock(), logging)  # type: ignore
-        abci_app.setup()
-        assert abci_app.synchronized_data
-        expected = f"No `synchronized_data_class` set on {abci_app._current_round_cls}"
-        assert expected in caplog.text
-        assert not isinstance(abci_app.synchronized_data, SynchronizedData)
-
     with mock.patch.object(AbciAppTest, "initial_round_cls") as m:
         m.synchronized_data_class = SynchronizedData
-        abci_app = AbciAppTest(synchronized_data, MagicMock(), logging)  # type: ignore
+        abci_app = AbciAppTest(synchronized_data, MagicMock(), logging.getLogger())
         abci_app.setup()
         assert isinstance(abci_app.synchronized_data, SynchronizedData)
-        assert abci_app.synchronized_data.dummy_attr == sentinel  # type: ignore
+        assert abci_app.synchronized_data.dummy_attr == sentinel
 
 
 def test_get_name() -> None:
