@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -45,7 +45,7 @@ from unittest import mock
 from unittest.mock import MagicMock
 
 import pytest
-import pytz  # type: ignore  # pylint: disable=import-error
+import pytz  # pylint: disable=import-error
 from _pytest.logging import LogCaptureFixture
 
 # pylint: skip-file
@@ -69,11 +69,13 @@ from packages.valory.skills.abstract_round_abci.base import (
     AbstractRound,
     BaseSynchronizedData,
     BaseTxPayload,
+    DegenerateRound,
     Transaction,
 )
 from packages.valory.skills.abstract_round_abci.behaviour_utils import (
     AsyncBehaviour,
     BaseBehaviour,
+    BaseBehaviourInternalError,
     DegenerateBehaviour,
     GENESIS_TIME_FMT,
     HEIGHT_OFFSET_MULTIPLIER,
@@ -85,6 +87,7 @@ from packages.valory.skills.abstract_round_abci.behaviour_utils import (
     SendException,
     TimeoutException,
     TmManager,
+    _MetaBaseBehaviour,
     make_degenerate_behaviour,
 )
 from packages.valory.skills.abstract_round_abci.io_.ipfs import (
@@ -419,6 +422,9 @@ class RoundA(AbstractRound):
     """Concrete ABCI round."""
 
     round_id = "round_a"
+    synchronized_data_class = BaseSynchronizedData
+    allowed_tx_type = MagicMock()
+    payload_attribute = MagicMock()
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
         """Handle end block."""
@@ -434,7 +440,6 @@ class RoundA(AbstractRound):
 class BehaviourATest(BaseBehaviour):
     """Concrete BaseBehaviour class."""
 
-    behaviour_id = "behaviour_a"
     matching_round: Type[RoundA] = RoundA
 
     def async_act(self) -> Generator:
@@ -533,6 +538,10 @@ class TestBaseBehaviour:
         self.behaviour = BehaviourATest(name="", skill_context=self.context_mock)
         self.behaviour.context.logger = logging  # type: ignore
 
+    def test_behaviour_id(self) -> None:
+        """Test behaviour_id on instance."""
+        assert self.behaviour.behaviour_id == BehaviourATest.auto_behaviour_id()
+
     def test_send_to_ipfs(self, caplog: LogCaptureFixture) -> None:
         """Test send_to_ipfs"""
 
@@ -1209,7 +1218,7 @@ class TestBaseBehaviour:
             "create",
             return_value=(MagicMock(), MagicMock()),
         ):
-            self.behaviour.context.default_ledger_id = "default_ledger_id"  # type: ignore
+            self.behaviour.context.default_ledger_id = "default_ledger_id"
             self.behaviour._send_transaction_receipt_request("digest")
 
     def test_build_http_request_message(self, *_: Any) -> None:
@@ -1618,7 +1627,7 @@ class TestBaseBehaviour:
 
     def test_default_callback_late_arriving_message(self, *_: Any) -> None:
         """Test 'default_callback_request' when a message arrives late."""
-        self.behaviour._AsyncBehaviour__stopped = False  # type: ignore
+        self.behaviour._AsyncBehaviour__stopped = False
         message = MagicMock()
         current_behaviour = MagicMock()
         with mock.patch.object(self.behaviour.context.logger, "warning") as info_mock:
@@ -1626,7 +1635,7 @@ class TestBaseBehaviour:
             info_mock.assert_called_with(
                 "No callback defined for request with nonce: "
                 f"{message.dialogue_reference.__getitem__()}, "
-                f"arriving for behaviour: behaviour_a"
+                f"arriving for behaviour: {self.behaviour.behaviour_id}"
             )
 
     def test_default_callback_request_waiting_message(self, *_: Any) -> None:
@@ -1931,6 +1940,7 @@ def test_degenerate_behaviour_async_act() -> None:
 
         behaviour_id = "concrete_degenerate_behaviour"
         matching_round = MagicMock()
+        sleep_time_before_exit = 0.01
 
     context = MagicMock()
     context.params.ipfs_domain_name = None
@@ -1944,17 +1954,37 @@ def test_degenerate_behaviour_async_act() -> None:
         SystemExit,
     ):
         behaviour.act()
+        time.sleep(0.02)
+        behaviour.act()
 
 
 def test_make_degenerate_behaviour() -> None:
     """Test 'make_degenerate_behaviour'."""
-    round_id = "round_id"
-    new_cls = make_degenerate_behaviour(round_id)
+
+    class FinalRound(DegenerateRound):
+        """A final round for testing."""
+
+        synchronized_data_class = BaseSynchronizedData
+
+        def check_payload(self, payload: BaseTxPayload) -> None:
+            pass
+
+        def process_payload(self, payload: BaseTxPayload) -> None:
+            pass
+
+        def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Enum]]:
+            pass
+
+    new_cls = make_degenerate_behaviour(FinalRound)
 
     assert isinstance(new_cls, type)
     assert issubclass(new_cls, DegenerateBehaviour)
+    assert new_cls.matching_round == FinalRound
 
-    assert new_cls.auto_behaviour_id() == f"degenerate_behaviour_{round_id}"
+    assert (
+        new_cls.auto_behaviour_id()
+        == f"degenerate_behaviour_{FinalRound.auto_round_id()}"
+    )
 
 
 class TestTmManager:
@@ -2143,3 +2173,18 @@ class TestTmManager:
 
         self.tm_manager._active_generator = None
         assert not self.tm_manager.is_acting
+
+
+def test_meta_base_behaviour_when_instance_not_subclass_of_base_behaviour() -> None:
+    """Test instantiation of meta class when instance not a subclass of BaseBehaviour."""
+
+    class MyBaseBehaviour(metaclass=_MetaBaseBehaviour):
+        pass
+
+
+def test_base_behaviour_instantiation_without_attributes_raises_error() -> None:
+    """Test that definition of concrete subclass of BaseBehaviour without attributes raises error."""
+    with pytest.raises(BaseBehaviourInternalError):
+
+        class MyBaseBehaviour(BaseBehaviour):
+            pass
