@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@
 """This module contains the behaviours for the 'abci' skill."""
 import datetime
 import json
+from abc import ABC
 from enum import Enum
 from typing import Any, Dict, Generator, Optional, Set, Type, cast
 
@@ -53,7 +54,7 @@ NODE = "node_{address}"
 WAIT_FOR_BLOCK_TIMEOUT = 60.0  # 1 minute
 
 
-class RegistrationBaseBehaviour(BaseBehaviour):
+class RegistrationBaseBehaviour(BaseBehaviour, ABC):
     """Agent registration to the FSM App."""
 
     def async_act(self) -> Generator:
@@ -457,8 +458,8 @@ class AgentRegistrationRoundBehaviour(AbstractRoundBehaviour):
     """This behaviour manages the consensus stages for the registration."""
 
     initial_behaviour_cls = RegistrationStartupBehaviour
-    abci_app_cls = AgentRegistrationAbciApp  # type: ignore
-    behaviours: Set[Type[BaseBehaviour]] = {  # type: ignore
+    abci_app_cls = AgentRegistrationAbciApp
+    behaviours: Set[Type[BaseBehaviour]] = {
         RegistrationBehaviour,  # type: ignore
         RegistrationStartupBehaviour,  # type: ignore
     }
