@@ -39,7 +39,7 @@ from packages.valory.skills.abstract_round_abci.handlers import (
 )
 
 
-ABCIRoundHandler = BaseABCIRoundHandler
+ABCIHandler = BaseABCIRoundHandler
 HttpHandler = BaseHttpHandler
 SigningHandler = BaseSigningHandler
 LedgerApiHandler = BaseLedgerApiHandler
