@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -60,7 +60,6 @@ from packages.valory.skills.registration_abci.rounds import (
 )
 from packages.valory.skills.registration_abci.rounds import (
     Event,
-    FinishedRegistrationFFWRound,
     FinishedRegistrationRound,
 )
 
@@ -167,17 +166,15 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
     """Test case to test RegistrationStartupBehaviour."""
 
     behaviour_class = RegistrationStartupBehaviour
-    next_behaviour_class = make_degenerate_behaviour(
-        FinishedRegistrationRound.auto_round_id()
-    )
+    next_behaviour_class = make_degenerate_behaviour(FinishedRegistrationRound)
 
     other_agents: List[str] = ["0xAlice", "0xBob", "0xCharlie"]
     _time_in_future = datetime.datetime.now() + datetime.timedelta(hours=10)
     _time_in_past = datetime.datetime.now() - datetime.timedelta(hours=10)
 
-    def setup(self, **kwargs: Any) -> None:  # type: ignore
+    def setup(self, **kwargs: Any) -> None:
         """Setup"""
-        super().setup()
+        super().setup(**kwargs)
         self.state.params.sleep_time = 0.01
         self.state.params.share_tm_config_on_startup = True
 
@@ -588,15 +585,11 @@ class TestRegistrationStartupBehaviourNoConfigShare(BaseRegistrationTestBehaviou
     """Test case to test RegistrationBehaviour."""
 
     behaviour_class = RegistrationStartupBehaviour
-    next_behaviour_class = make_degenerate_behaviour(
-        FinishedRegistrationRound.auto_round_id()
-    )
+    next_behaviour_class = make_degenerate_behaviour(FinishedRegistrationRound)
 
 
 class TestRegistrationBehaviour(BaseRegistrationTestBehaviour):
     """Test case to test RegistrationBehaviour."""
 
     behaviour_class = RegistrationBehaviour
-    next_behaviour_class = make_degenerate_behaviour(
-        FinishedRegistrationFFWRound.auto_round_id()
-    )
+    next_behaviour_class = make_degenerate_behaviour(FinishedRegistrationRound)
