@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@
 # ------------------------------------------------------------------------------
 
 """This module contains the behaviours for the 'abci' skill."""
+
 import binascii
 import pprint
 import re
@@ -775,7 +776,7 @@ class FinalizeBehaviour(TransactionSettlementBaseBehaviour):
                 self.context.logger.error(
                     "Trying to finalize a transaction which has been verified already!"
                 )
-            else:
+            else:  # pragma: no cover
                 self.context.logger.info(
                     f"Finalization tx digest: {cast(str, tx_data['tx_digest'])}"
                 )
@@ -784,6 +785,7 @@ class FinalizeBehaviour(TransactionSettlementBaseBehaviour):
                 )
 
             tx_hashes_history = self.synchronized_data.tx_hashes_history
+
             if tx_data["tx_digest"] != "":
                 tx_hashes_history.append(cast(str, tx_data["tx_digest"]))
 
@@ -883,7 +885,7 @@ class TransactionSettlementRoundBehaviour(AbstractRoundBehaviour):
     """This behaviour manages the consensus stages for the basic transaction settlement."""
 
     initial_behaviour_cls = RandomnessTransactionSubmissionBehaviour
-    abci_app_cls = TransactionSubmissionAbciApp  # type: ignore
+    abci_app_cls = TransactionSubmissionAbciApp
     behaviours: Set[Type[BaseBehaviour]] = {
         RandomnessTransactionSubmissionBehaviour,  # type: ignore
         SelectKeeperTransactionSubmissionBehaviourA,  # type: ignore
