@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2021-2022 Valory AG
+#   Copyright 2021-2023 Valory AG
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -88,11 +88,6 @@ class SynchronizedData(
     This data is replicated by the tendermint application.
     """
 
-    @property
-    def safe_contract_address(self) -> str:
-        """Get the safe contract address."""
-        return cast(str, self.db.get_strict("safe_contract_address"))
-
     @property
     def participant_to_signature(self) -> Mapping[str, SignaturePayload]:
         """Get the participant_to_signature."""
@@ -159,7 +154,9 @@ class SynchronizedData(
         :return: the tx hash which is ready for validation.
         """
         if not self.tx_hashes_history:
-            raise ValueError("FSM design error: tx hash should exist")
+            raise ValueError(
+                "FSM design error: tx hash should exist"
+            )  # pragma: no cover
         return self.tx_hashes_history[-1]
 
     @property
@@ -198,13 +195,15 @@ class SynchronizedData(
         return [h for hashes in parsed_hashes for h in hashes]
 
     @property
-    def most_voted_check_result(self) -> str:
+    def most_voted_check_result(self) -> str:  # pragma: no cover
         """Get the most voted checked result."""
         return cast(str, self.db.get_strict("most_voted_check_result"))
 
     @property
-    def participant_to_check(self) -> Mapping[str, CheckTransactionHistoryPayload]:
-        """Get the mapping from pariticipants to checks."""
+    def participant_to_check(
+        self,
+    ) -> Mapping[str, CheckTransactionHistoryPayload]:  # pragma: no cover
+        """Get the mapping from participants to checks."""
         return cast(
             Mapping[str, CheckTransactionHistoryPayload],
             self.db.get_strict("participant_to_check"),
@@ -401,7 +400,7 @@ class ValidateTransactionRound(VotingRound):
                     ): VerificationStatus.VERIFIED,
                     get_name(SynchronizedData.final_tx_hash): final_tx_hash,
                 },
-            )  # type: ignore
+            )
             return synchronized_data, self.done_event
         if self.negative_vote_threshold_reached:
             return self.synchronized_data, self.negative_event
@@ -709,7 +708,6 @@ class TransactionSubmissionAbciApp(AbciApp[Event]):
     }
     db_pre_conditions: Dict[AppState, List[str]] = {
         RandomnessTransactionSubmissionRound: [
-            get_name(SynchronizedData.safe_contract_address),
             get_name(SynchronizedData.most_voted_tx_hash),
             get_name(SynchronizedData.participants),
         ]
